# coding: utf-8

# flake8: noqa

"""
    国税庁API

    国税庁が提供するインボイス制度適格請求書発行事業者公表システムWeb-APIを使用するためのクライアントAPI(https://www.invoice-kohyo.nta.go.jp/web-api/index.html)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package
from openapi_client.api.v1_api import V1Api

# import ApiClient
from openapi_client.api_response import ApiResponse
from openapi_client.api_client import ApiClient
from openapi_client.configuration import Configuration
from openapi_client.exceptions import OpenApiException
from openapi_client.exceptions import ApiTypeError
from openapi_client.exceptions import ApiValueError
from openapi_client.exceptions import ApiKeyError
from openapi_client.exceptions import ApiAttributeError
from openapi_client.exceptions import ApiException

# import models into sdk package
from openapi_client.models.announcement import Announcement
from openapi_client.models.response_body import ResponseBody



# coding: utf-8

"""
    国税庁API

    国税庁が提供するインボイス制度適格請求書発行事業者公表システムWeb-APIを使用するためのクライアントAPI(https://www.invoice-kohyo.nta.go.jp/web-api/index.html)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from openapi_client.models.response_body import ResponseBody  # noqa: E501

class TestResponseBody(unittest.TestCase):
    """ResponseBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseBody:
        """Test ResponseBody
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseBody`
        """
        model = ResponseBody()  # noqa: E501
        if include_optional:
            return ResponseBody(
                last_update_date = 'Mon Nov 01 09:00:00 JST 2021',
                count = '1',
                divide_number = '1',
                divide_size = '1',
                announcement = [
                    openapi_client.models.announcement.Announcement(
                        sequence_number = '1', 
                        registrated_number = 'T8040001999011', 
                        process = '1', 
                        correct = '0', 
                        kind = '2', 
                        country = '1', 
                        latest = '1', 
                        registration_date = 'Sun Oct 01 09:00:00 JST 2023', 
                        update_date = 'Mon Nov 01 09:00:00 JST 2021', 
                        disposal_date = '', 
                        expire_date = '', 
                        address = '北海道札幌市中央区大通西１０丁目', 
                        address_prefecture_code = '1', 
                        address_city_code = '101', 
                        address_request = '', 
                        address_request_prefecture_code = '', 
                        address_request_city_code = '', 
                        kana = '', 
                        name = '株式会社インボイス公表', 
                        address_inside = '', 
                        address_inside_prefecture_code = '', 
                        address_inside_city_code = '', 
                        trade_name = '', 
                        popular_name_previous_name = '', )
                    ]
            )
        else:
            return ResponseBody(
        )
        """

    def testResponseBody(self):
        """Test ResponseBody"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    国税庁API

    国税庁が提供するインボイス制度適格請求書発行事業者公表システムWeb-APIを使用するためのクライアントAPI(https://www.invoice-kohyo.nta.go.jp/web-api/index.html)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.api.v1_api import V1Api  # noqa: E501


class TestV1Api(unittest.TestCase):
    """V1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = V1Api()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_get_announcement_by_diff(self) -> None:
        """Test case for get_announcement_by_diff

        取得期間を指定して情報を取得  # noqa: E501
        """
        pass

    def test_get_announcement_by_number(self) -> None:
        """Test case for get_announcement_by_number

        登録番号を指定して情報を取得  # noqa: E501
        """
        pass

    def test_get_announcement_by_valid(self) -> None:
        """Test case for get_announcement_by_valid

        登録番号と日付を指定して情報を取得  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    国税庁API

    国税庁が提供するインボイス制度適格請求書発行事業者公表システムWeb-APIを使用するためのクライアントAPI(https://www.invoice-kohyo.nta.go.jp/web-api/index.html)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from kendama.models.announcement import Announcement
from kendama.models.response_body import ResponseBody



# coding: utf-8

# flake8: noqa

"""
    国税庁API

    国税庁が提供するインボイス制度適格請求書発行事業者公表システムWeb-APIを使用するためのクライアントAPI(https://www.invoice-kohyo.nta.go.jp/web-api/index.html)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.1.2"

# import apis into sdk package
from kendama.api.v1_api import V1Api

# import ApiClient
from kendama.api_response import ApiResponse
from kendama.api_client import ApiClient
from kendama.configuration import Configuration
from kendama.exceptions import OpenApiException
from kendama.exceptions import ApiTypeError
from kendama.exceptions import ApiValueError
from kendama.exceptions import ApiKeyError
from kendama.exceptions import ApiAttributeError
from kendama.exceptions import ApiException

# import models into sdk package
from kendama.models.announcement import Announcement
from kendama.models.response_body import ResponseBody



# coding: utf-8

"""
    国税庁API

    国税庁が提供するインボイス制度適格請求書発行事業者公表システムWeb-APIを使用するためのクライアントAPI(https://www.invoice-kohyo.nta.go.jp/web-api/index.html)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date
from typing import Optional
from pydantic import BaseModel, Field, StrictStr, constr, validator

class Announcement(BaseModel):
    """
    Announcement
    """
    sequence_number: constr(strict=True, max_length=8, min_length=1) = Field(..., alias="sequenceNumber", description="一連番号")
    registrated_number: StrictStr = Field(..., alias="registratedNumber", description="登録番号")
    process: StrictStr = Field(..., description="事業者処理区分")
    correct: StrictStr = Field(..., description="訂正区分")
    kind: StrictStr = Field(..., description="人格区分")
    country: StrictStr = Field(..., description="国内外区分")
    latest: StrictStr = Field(..., description="最新履歴")
    registration_date: date = Field(..., alias="registrationDate", description="登録年月日")
    update_date: date = Field(..., alias="updateDate", description="更新年月日")
    disposal_date: StrictStr = Field(..., alias="disposalDate", description="取消年月日")
    expire_date: StrictStr = Field(..., alias="expireDate", description="失効年月日")
    address: constr(strict=True, max_length=600) = Field(..., description="本店又は主たる事務所の所在地（法人）")
    address_prefecture_code: StrictStr = Field(..., alias="addressPrefectureCode", description="本店又は主たる事務所の所在地都道府県コード（法人）")
    address_city_code: StrictStr = Field(..., alias="addressCityCode", description="本店又は主たる事務所の所在地市区町村コード（法人）")
    address_request: constr(strict=True, max_length=600) = Field(..., alias="addressRequest", description="本店又は主たる事務所の所在地（公表申出）")
    address_request_prefecture_code: StrictStr = Field(..., alias="addressRequestPrefectureCode", description="本店又は主たる事務所の所在地都道府県コード（公表申出）")
    address_request_city_code: StrictStr = Field(..., alias="addressRequestCityCode", description="本店又は主たる事務所の所在地市区町村コード（公表申出）")
    kana: constr(strict=True, max_length=500) = Field(..., description="日本語（カナ）")
    name: constr(strict=True, max_length=300) = Field(..., description="氏名又は名称")
    address_inside: constr(strict=True, max_length=300) = Field(..., alias="addressInside", description="国内において行う資産の譲渡等に係る事務所、事業所その他これらに準ずるものの所在地")
    address_inside_prefecture_code: Optional[StrictStr] = Field(None, alias="addressInsidePrefectureCode", description="国内において行う資産の譲渡等に係る事務所、事業所その他これらに準ずるものの所在地都道府県コード")
    address_inside_city_code: StrictStr = Field(..., alias="addressInsideCityCode", description="国内において行う資産の譲渡等に係る事務所、事業所その他これらに準ずるものの所在地市区町村コード")
    trade_name: constr(strict=True, max_length=200) = Field(..., alias="tradeName", description="主たる屋号")
    popular_name_previous_name: constr(strict=True, max_length=200) = Field(..., alias="popularName_previousName", description="通称・旧姓")
    __properties = ["sequenceNumber", "registratedNumber", "process", "correct", "kind", "country", "latest", "registrationDate", "updateDate", "disposalDate", "expireDate", "address", "addressPrefectureCode", "addressCityCode", "addressRequest", "addressRequestPrefectureCode", "addressRequestCityCode", "kana", "name", "addressInside", "addressInsidePrefectureCode", "addressInsideCityCode", "tradeName", "popularName_previousName"]

    @validator('process')
    def process_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('01', '02', '03', '04', '99'):
            raise ValueError("must be one of enum values ('01', '02', '03', '04', '99')")
        return value

    @validator('correct')
    def correct_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('0', '1', ''):
            raise ValueError("must be one of enum values ('0', '1', '')")
        return value

    @validator('kind')
    def kind_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('1', '2'):
            raise ValueError("must be one of enum values ('1', '2')")
        return value

    @validator('country')
    def country_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('1', '2', '3'):
            raise ValueError("must be one of enum values ('1', '2', '3')")
        return value

    @validator('latest')
    def latest_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('0', '1'):
            raise ValueError("must be one of enum values ('0', '1')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Announcement:
        """Create an instance of Announcement from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Announcement:
        """Create an instance of Announcement from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Announcement.parse_obj(obj)

        _obj = Announcement.parse_obj({
            "sequence_number": obj.get("sequenceNumber"),
            "registrated_number": obj.get("registratedNumber"),
            "process": obj.get("process"),
            "correct": obj.get("correct"),
            "kind": obj.get("kind"),
            "country": obj.get("country"),
            "latest": obj.get("latest"),
            "registration_date": obj.get("registrationDate"),
            "update_date": obj.get("updateDate"),
            "disposal_date": obj.get("disposalDate"),
            "expire_date": obj.get("expireDate"),
            "address": obj.get("address"),
            "address_prefecture_code": obj.get("addressPrefectureCode"),
            "address_city_code": obj.get("addressCityCode"),
            "address_request": obj.get("addressRequest"),
            "address_request_prefecture_code": obj.get("addressRequestPrefectureCode"),
            "address_request_city_code": obj.get("addressRequestCityCode"),
            "kana": obj.get("kana"),
            "name": obj.get("name"),
            "address_inside": obj.get("addressInside"),
            "address_inside_prefecture_code": obj.get("addressInsidePrefectureCode"),
            "address_inside_city_code": obj.get("addressInsideCityCode"),
            "trade_name": obj.get("tradeName"),
            "popular_name_previous_name": obj.get("popularName_previousName")
        })
        return _obj





# coding: utf-8

"""
    国税庁API

    国税庁が提供するインボイス制度適格請求書発行事業者公表システムWeb-APIを使用するためのクライアントAPI(https://www.invoice-kohyo.nta.go.jp/web-api/index.html)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date
from typing import List, Optional
from pydantic import BaseModel, Field, conlist, constr
from openapi_client.models.announcement import Announcement

class ResponseBody(BaseModel):
    """
    ResponseBody
    """
    last_update_date: Optional[date] = Field(None, alias="lastUpdateDate", description="最終更新年月日")
    count: Optional[constr(strict=True, max_length=8, min_length=1)] = Field(None, description="総件数")
    divide_number: Optional[constr(strict=True, max_length=6, min_length=1)] = Field(None, alias="divideNumber", description="分割番号")
    divide_size: Optional[constr(strict=True, max_length=6, min_length=1)] = Field(None, alias="divideSize", description="分割数")
    announcement: Optional[conlist(Announcement)] = None
    __properties = ["lastUpdateDate", "count", "divideNumber", "divideSize", "announcement"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ResponseBody:
        """Create an instance of ResponseBody from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in announcement (list)
        _items = []
        if self.announcement:
            for _item in self.announcement:
                if _item:
                    _items.append(_item.to_dict())
            _dict['announcement'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ResponseBody:
        """Create an instance of ResponseBody from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ResponseBody.parse_obj(obj)

        _obj = ResponseBody.parse_obj({
            "last_update_date": obj.get("lastUpdateDate"),
            "count": obj.get("count"),
            "divide_number": obj.get("divideNumber"),
            "divide_size": obj.get("divideSize"),
            "announcement": [Announcement.from_dict(_item) for _item in obj.get("announcement")] if obj.get("announcement") is not None else None
        })
        return _obj





# coding: utf-8

"""
    国税庁API

    国税庁が提供するインボイス制度適格請求書発行事業者公表システムWeb-APIを使用するためのクライアントAPI(https://www.invoice-kohyo.nta.go.jp/web-api/index.html)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError

from datetime import date

from pydantic import StrictStr, constr

from typing import Optional

from openapi_client.models.response_body import ResponseBody

from openapi_client.api_client import ApiClient
from openapi_client.api_response import ApiResponse
from openapi_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class V1Api:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def get_announcement_by_diff(self, id : StrictStr, var_from : date, to : date, type : StrictStr, division : Optional[StrictStr] = None, divide : Optional[constr(strict=True, max_length=999999, min_length=1)] = None, **kwargs) -> ResponseBody:  # noqa: E501
        """取得期間を指定して情報を取得  # noqa: E501

        取得期間を指定し、当該期間内に「更新年月日」が含まれる公表情報を取得  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_announcement_by_diff(id, var_from, to, type, division, divide, async_req=True)
        >>> result = thread.get()

        :param id: (required)
        :type id: str
        :param var_from: (required)
        :type var_from: date
        :param to: (required)
        :type to: date
        :param type: (required)
        :type type: str
        :param division:
        :type division: str
        :param divide:
        :type divide: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResponseBody
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the get_announcement_by_diff_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_announcement_by_diff_with_http_info(id, var_from, to, type, division, divide, **kwargs)  # noqa: E501

    @validate_arguments
    def get_announcement_by_diff_with_http_info(self, id : StrictStr, var_from : date, to : date, type : StrictStr, division : Optional[StrictStr] = None, divide : Optional[constr(strict=True, max_length=999999, min_length=1)] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """取得期間を指定して情報を取得  # noqa: E501

        取得期間を指定し、当該期間内に「更新年月日」が含まれる公表情報を取得  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_announcement_by_diff_with_http_info(id, var_from, to, type, division, divide, async_req=True)
        >>> result = thread.get()

        :param id: (required)
        :type id: str
        :param var_from: (required)
        :type var_from: date
        :param to: (required)
        :type to: date
        :param type: (required)
        :type type: str
        :param division:
        :type division: str
        :param divide:
        :type divide: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResponseBody, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id',
            'var_from',
            'to',
            'type',
            'division',
            'divide'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_announcement_by_diff" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('id') is not None:  # noqa: E501
            _query_params.append(('id', _params['id']))

        if _params.get('var_from') is not None:  # noqa: E501
            if isinstance(_params['var_from'], date):
                _query_params.append(('from', _params['var_from'].strftime(self.api_client.configuration.date_format)))
            else:
                _query_params.append(('from', _params['var_from']))

        if _params.get('to') is not None:  # noqa: E501
            if isinstance(_params['to'], date):
                _query_params.append(('to', _params['to'].strftime(self.api_client.configuration.date_format)))
            else:
                _query_params.append(('to', _params['to']))

        if _params.get('type') is not None:  # noqa: E501
            _query_params.append(('type', _params['type']))

        if _params.get('division') is not None:  # noqa: E501
            _query_params.append(('division', _params['division']))

        if _params.get('divide') is not None:  # noqa: E501
            _query_params.append(('divide', _params['divide']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "ResponseBody",
        }

        return self.api_client.call_api(
            '/1/diff', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_announcement_by_number(self, id : StrictStr, number : StrictStr, type : StrictStr, history : Optional[StrictStr] = None, **kwargs) -> ResponseBody:  # noqa: E501
        """登録番号を指定して情報を取得  # noqa: E501

        指定された登録番号に係る登録年月日、取消年月日及び失効年月日に紐づく最新情報（履歴情報は任意）を取得  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_announcement_by_number(id, number, type, history, async_req=True)
        >>> result = thread.get()

        :param id: (required)
        :type id: str
        :param number: (required)
        :type number: str
        :param type: (required)
        :type type: str
        :param history:
        :type history: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResponseBody
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the get_announcement_by_number_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_announcement_by_number_with_http_info(id, number, type, history, **kwargs)  # noqa: E501

    @validate_arguments
    def get_announcement_by_number_with_http_info(self, id : StrictStr, number : StrictStr, type : StrictStr, history : Optional[StrictStr] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """登録番号を指定して情報を取得  # noqa: E501

        指定された登録番号に係る登録年月日、取消年月日及び失効年月日に紐づく最新情報（履歴情報は任意）を取得  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_announcement_by_number_with_http_info(id, number, type, history, async_req=True)
        >>> result = thread.get()

        :param id: (required)
        :type id: str
        :param number: (required)
        :type number: str
        :param type: (required)
        :type type: str
        :param history:
        :type history: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResponseBody, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id',
            'number',
            'type',
            'history'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_announcement_by_number" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('id') is not None:  # noqa: E501
            _query_params.append(('id', _params['id']))

        if _params.get('number') is not None:  # noqa: E501
            _query_params.append(('number', _params['number']))

        if _params.get('type') is not None:  # noqa: E501
            _query_params.append(('type', _params['type']))

        if _params.get('history') is not None:  # noqa: E501
            _query_params.append(('history', _params['history']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "ResponseBody",
        }

        return self.api_client.call_api(
            '/1/num', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_announcement_by_valid(self, id : StrictStr, number : StrictStr, day : date, type : StrictStr, **kwargs) -> ResponseBody:  # noqa: E501
        """登録番号と日付を指定して情報を取得  # noqa: E501

        登録番号及び指定された日付を基準日とした直近の登録年月日、取消年月日、失効年月日に紐づく情報を取得  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_announcement_by_valid(id, number, day, type, async_req=True)
        >>> result = thread.get()

        :param id: (required)
        :type id: str
        :param number: (required)
        :type number: str
        :param day: (required)
        :type day: date
        :param type: (required)
        :type type: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResponseBody
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the get_announcement_by_valid_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_announcement_by_valid_with_http_info(id, number, day, type, **kwargs)  # noqa: E501

    @validate_arguments
    def get_announcement_by_valid_with_http_info(self, id : StrictStr, number : StrictStr, day : date, type : StrictStr, **kwargs) -> ApiResponse:  # noqa: E501
        """登録番号と日付を指定して情報を取得  # noqa: E501

        登録番号及び指定された日付を基準日とした直近の登録年月日、取消年月日、失効年月日に紐づく情報を取得  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_announcement_by_valid_with_http_info(id, number, day, type, async_req=True)
        >>> result = thread.get()

        :param id: (required)
        :type id: str
        :param number: (required)
        :type number: str
        :param day: (required)
        :type day: date
        :param type: (required)
        :type type: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResponseBody, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id',
            'number',
            'day',
            'type'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_announcement_by_valid" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('id') is not None:  # noqa: E501
            _query_params.append(('id', _params['id']))

        if _params.get('number') is not None:  # noqa: E501
            _query_params.append(('number', _params['number']))

        if _params.get('day') is not None:  # noqa: E501
            if isinstance(_params['day'], date):
                _query_params.append(('day', _params['day'].strftime(self.api_client.configuration.date_format)))
            else:
                _query_params.append(('day', _params['day']))

        if _params.get('type') is not None:  # noqa: E501
            _query_params.append(('type', _params['type']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "ResponseBody",
        }

        return self.api_client.call_api(
            '/1/valid', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    国税庁API

    国税庁が提供するインボイス制度適格請求書発行事業者公表システムWeb-APIを使用するためのクライアントAPI(https://www.invoice-kohyo.nta.go.jp/web-api/index.html)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "kendama"
VERSION = "0.1.2"
PYTHON_REQUIRES = ">=3.7"
REQUIRES = [
    "urllib3 >= 1.25.3, < 2.1.0",
    "python-dateutil",
    "pydantic >= 1.10.5, < 2",
    "aenum"
]

setup(
    name=NAME,
    version=VERSION,
    description="国税庁API",
    author="uichi",
    author_email="37263474+uichi@users.noreply.github.com",
    url="https://github.com/uichi/kendama-python",
    license="MIT",
    keywords=["OpenAPI", "OpenAPI-Generator", "国税庁API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description_content_type='text/markdown',
    long_description=open('README.md').read(),
    package_data={"kendama": ["py.typed"]},
    project_urls={
        'Documentation': 'https://github.com/uichi/kendama-python/blob/main/README.md',
        'Source': 'https://github.com/uichi/kendama-python'
    }
)
